@@ -5,6 +5,7 @@ import (
 	"strings"
 
 	"github.com/git-town/git-town/v14/src/cli/dialog/components"
+	"github.com/git-town/git-town/v14/src/cli/dialog/components/list"
 	"github.com/git-town/git-town/v14/src/config/configdomain"
 	"github.com/git-town/git-town/v14/src/messages"
 )
@@ -27,10 +28,10 @@ const (
 )
 
 func SyncFeatureStrategy(existing configdomain.SyncFeatureStrategy, inputs components.TestInput) (configdomain.SyncFeatureStrategy, bool, error) {
-	entries := []syncFeatureStrategyEntry{
+	entries := list.NewEntries(
 		syncFeatureStrategyEntryMerge,
 		syncFeatureStrategyEntryRebase,
-	}
+	)
 	var defaultPos int
 	switch existing {
 	case configdomain.SyncFeatureStrategyMerge:
@@ -40,13 +41,13 @@ func SyncFeatureStrategy(existing configdomain.SyncFeatureStrategy, inputs compo
 	default:
 		panic("unknown sync-feature-strategy: " + existing.String())
 	}
-	selection, aborted, err := components.RadioList(entries, defaultPos, syncFeatureStrategyTitle, SyncFeatureStrategyHelp, inputs)
+	selection, aborted, err := components.RadioList(list.NewEntries(entries...), defaultPos, syncFeatureStrategyTitle, SyncFeatureStrategyHelp, inputs)
 	if err != nil || aborted {
 		return configdomain.SyncFeatureStrategyMerge, aborted, err
 	}
 	cutSelection, _, _ := strings.Cut(selection.String(), " ")
 	fmt.Printf(messages.SyncFeatureBranches, components.FormattedSelection(cutSelection, aborted))
-	return selection.SyncFeatureStrategy(), aborted, err
+	return selection.Data.SyncFeatureStrategy(), aborted, err
 }
 
 type syncFeatureStrategyEntry string
