@@ -4,10 +4,11 @@ import (
 	"fmt"
 
 	"github.com/git-town/git-town/v14/src/cli/colors"
+	"github.com/git-town/git-town/v14/src/gohacks"
 	"github.com/git-town/git-town/v14/src/messages"
 )
 
-func Footer(verbose bool, commandsCount int, finalMessages []string) {
+func Footer(verbose bool, commandsCount gohacks.Counter, finalMessages []string) {
 	fmt.Println()
 	if verbose {
 		fmt.Printf(messages.CommandsRun, commandsCount)
