@@ -114,7 +114,7 @@ type compressBranchesData struct {
 	branchesToCompress  []compressBranchData
 	compressEntireStack bool
 	config              config.ValidatedConfig
-	dialogTestInputs    components.TestInputs
+	dialogTestInputs    Mutable[components.TestInputs]
 	dryRun              bool
 	hasOpenChanges      bool
 	initialBranch       gitdomain.LocalBranchName
@@ -131,12 +131,12 @@ type compressBranchData struct {
 	parentBranch     gitdomain.LocalBranchName
 }
 
-func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun, verbose bool, message Option[gitdomain.CommitMessage], compressEntireStack bool) (*compressBranchesData, bool, error) {
+func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun, verbose bool, message Option[gitdomain.CommitMessage], compressEntireStack bool) (data compressBranchesData, exit bool, err error) {
 	previousBranch := repo.Git.PreviouslyCheckedOutBranch(repo.Backend)
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
 	repoStatus, err := repo.Git.RepoStatus(repo.Backend)
 	if err != nil {
-		return nil, false, err
+		return data, false, err
 	}
 	branchesSnapshot, stashSize, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
 		Backend:               repo.Backend,
@@ -156,11 +156,11 @@ func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun, verbose
 		Verbose:               verbose,
 	})
 	if err != nil || exit {
-		return nil, exit, err
+		return data, exit, err
 	}
 	initialBranch, hasInitialBranch := branchesSnapshot.Active.Get()
 	if !hasInitialBranch {
-		return nil, exit, errors.New(messages.CurrentBranchCannotDetermine)
+		return data, exit, errors.New(messages.CurrentBranchCannotDetermine)
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
@@ -176,7 +176,7 @@ func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun, verbose
 		Unvalidated:        repo.UnvalidatedConfig,
 	})
 	if err != nil || exit {
-		return nil, exit, err
+		return data, exit, err
 	}
 	var branchNamesToCompress gitdomain.LocalBranchNames
 	if compressEntireStack {
@@ -188,19 +188,19 @@ func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun, verbose
 	for _, branchNameToCompress := range branchNamesToCompress {
 		branchInfo, hasBranchInfo := branchesSnapshot.Branches.FindByLocalName(branchNameToCompress).Get()
 		if !hasBranchInfo {
-			return nil, exit, fmt.Errorf(messages.CompressNoBranchInfo, branchNameToCompress)
+			return data, exit, fmt.Errorf(messages.CompressNoBranchInfo, branchNameToCompress)
 		}
 		branchType := validatedConfig.Config.BranchType(branchNameToCompress.BranchName().LocalName())
 		if err := validateCanCompressBranchType(branchNameToCompress, branchType); err != nil {
-			return nil, exit, err
+			return data, exit, err
 		}
 		if err := validateBranchIsSynced(branchNameToCompress, branchInfo.SyncStatus); err != nil {
-			return nil, exit, err
+			return data, exit, err
 		}
 		parent := validatedConfig.Config.Lineage.Parent(branchNameToCompress)
 		commits, err := repo.Git.CommitsInBranch(repo.Backend, branchNameToCompress.BranchName().LocalName(), parent)
 		if err != nil {
-			return nil, exit, err
+			return data, exit, err
 		}
 		commitCount := len(commits)
 		if commitCount == 0 {
@@ -214,7 +214,7 @@ func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun, verbose
 		}
 		parentBranch, hasParent := parent.Get()
 		if !hasParent {
-			return nil, exit, fmt.Errorf(messages.CompressBranchNoParent, branchNameToCompress)
+			return data, exit, fmt.Errorf(messages.CompressBranchNoParent, branchNameToCompress)
 		}
 		hasRemoteBranch, _, _ := branchInfo.HasRemoteBranch()
 		branchesToCompress = append(branchesToCompress, compressBranchData{
@@ -227,12 +227,12 @@ func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun, verbose
 		})
 	}
 	if len(branchesToCompress) == 0 {
-		return nil, exit, fmt.Errorf(messages.CompressNoCommits, branchNamesToCompress[0])
+		return data, exit, fmt.Errorf(messages.CompressNoCommits, branchNamesToCompress[0])
 	}
 	if len(branchesToCompress) == 1 && branchesToCompress[0].commitCount == 1 {
-		return nil, exit, fmt.Errorf(messages.CompressAlreadyOneCommit, branchNamesToCompress[0])
+		return data, exit, fmt.Errorf(messages.CompressAlreadyOneCommit, branchNamesToCompress[0])
 	}
-	return &compressBranchesData{
+	return compressBranchesData{
 		branchesSnapshot:    branchesSnapshot,
 		branchesToCompress:  branchesToCompress,
 		compressEntireStack: compressEntireStack,
@@ -246,34 +246,34 @@ func determineCompressBranchesData(repo execute.OpenRepoResult, dryRun, verbose
 	}, false, nil
 }
 
-func compressProgram(data *compressBranchesData) program.Program {
-	prog := program.Program{}
+func compressProgram(data compressBranchesData) program.Program {
+	prog := NewMutable(&program.Program{})
 	for _, branchToCompress := range data.branchesToCompress {
-		compressBranchProgram(&prog, branchToCompress, data.config.Config.Online(), data.initialBranch)
+		compressBranchProgram(prog, branchToCompress, data.config.Config.Online(), data.initialBranch)
 	}
-	prog.Add(&opcodes.Checkout{Branch: data.initialBranch.BranchName().LocalName()})
+	prog.Value.Add(&opcodes.Checkout{Branch: data.initialBranch.BranchName().LocalName()})
 	previousBranchCandidates := gitdomain.LocalBranchNames{}
 	if previousBranch, hasPreviousBranch := data.previousBranch.Get(); hasPreviousBranch {
 		previousBranchCandidates = append(previousBranchCandidates, previousBranch)
 	}
-	cmdhelpers.Wrap(&prog, cmdhelpers.WrapOptions{
+	cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
 		DryRun:                   data.dryRun,
 		RunInGitRoot:             true,
 		StashOpenChanges:         data.hasOpenChanges,
 		PreviousBranchCandidates: previousBranchCandidates,
 	})
-	return prog
+	return prog.Get()
 }
 
-func compressBranchProgram(prog *program.Program, data compressBranchData, online configdomain.Online, initialBranch gitdomain.LocalBranchName) {
+func compressBranchProgram(prog Mutable[program.Program], data compressBranchData, online configdomain.Online, initialBranch gitdomain.LocalBranchName) {
 	if !shouldCompressBranch(data.name, data.branchType, initialBranch) {
 		return
 	}
-	prog.Add(&opcodes.Checkout{Branch: data.name})
-	prog.Add(&opcodes.ResetCommitsInCurrentBranch{Parent: data.parentBranch})
-	prog.Add(&opcodes.CommitSquashedChanges{Message: Some(data.newCommitMessage)})
+	prog.Value.Add(&opcodes.Checkout{Branch: data.name})
+	prog.Value.Add(&opcodes.ResetCommitsInCurrentBranch{Parent: data.parentBranch})
+	prog.Value.Add(&opcodes.CommitSquashedChanges{Message: Some(data.newCommitMessage)})
 	if data.hasTracking && online.Bool() {
-		prog.Add(&opcodes.ForcePushCurrentBranch{})
+		prog.Value.Add(&opcodes.ForcePushCurrentBranch{})
 	}
 }
 
