@@ -138,19 +138,23 @@ func determineContributeData(args []string, repo execute.OpenRepoResult) (contri
 		if !hasCurrentBranch {
 			return contributeData{}, errors.New(messages.CurrentBranchCannotDetermine)
 		}
-		branchesToMark.Add(currentBranch, *repo.UnvalidatedConfig.Config)
+		branchesToMark.Add(currentBranch, repo.UnvalidatedConfig.Config.Get())
 		branchToCheckout = None[gitdomain.LocalBranchName]()
 	case 1:
 		branch := gitdomain.NewLocalBranchName(args[0])
-		branchesToMark.Add(branch, *repo.UnvalidatedConfig.Config)
-		branchInfo := branchesSnapshot.Branches.FindByRemoteName(branch.TrackingBranch())
+		branchesToMark.Add(branch, repo.UnvalidatedConfig.Config.Get())
+		trackingBranchName := branch.TrackingBranch()
+		branchInfo, hasBranchInfo := branchesSnapshot.Branches.FindByRemoteName(trackingBranchName).Get()
+		if !hasBranchInfo {
+			return contributeData{}, fmt.Errorf(messages.BranchDoesntExist, branch.String())
+		}
 		if branchInfo.SyncStatus == gitdomain.SyncStatusRemoteOnly {
 			branchToCheckout = Some(branch)
 		} else {
 			branchToCheckout = None[gitdomain.LocalBranchName]()
 		}
 	default:
-		branchesToMark.AddMany(gitdomain.NewLocalBranchNames(args...), *repo.UnvalidatedConfig.Config)
+		branchesToMark.AddMany(gitdomain.NewLocalBranchNames(args...), repo.UnvalidatedConfig.Config.Get())
 		branchToCheckout = None[gitdomain.LocalBranchName]()
 	}
 	return contributeData{
