@@ -17,7 +17,7 @@ func enterMainBranchCmd() *cobra.Command {
 			localBranches := gitdomain.NewLocalBranchNames("main", "branch-1", "branch-2", "branch-3", "branch-4", "branch-5", "branch-6", "branch-7", "branch-8", "branch-9", "branch-A", "branch-B")
 			main := gitdomain.NewLocalBranchName("main")
 			dialogInputs := components.LoadTestInputs(os.Environ())
-			_, _, err := dialog.MainBranch(localBranches, Some(main), dialogInputs.Next())
+			_, _, err := dialog.MainBranch(localBranches, Some(main), dialogInputs.Value.Next())
 			return err
 		},
 	}
