@@ -27,7 +27,7 @@ func enterPerennialBranches() *cobra.Command {
 			existingPerennialBranches := gitdomain.NewLocalBranchNames("branch-2", "branch-4")
 			main := gitdomain.NewLocalBranchName("main")
 			dialogTestInputs := components.LoadTestInputs(os.Environ())
-			_, _, err = dialog.PerennialBranches(localBranches, existingPerennialBranches, main, dialogTestInputs.Next())
+			_, _, err = dialog.PerennialBranches(localBranches, existingPerennialBranches, main, dialogTestInputs.Value.Next())
 			return err
 		},
 	}
