@@ -13,7 +13,7 @@ func enterSyncBeforeShip() *cobra.Command {
 		Use: "sync-before-ship",
 		RunE: func(_ *cobra.Command, _ []string) error {
 			dialogTestInputs := components.LoadTestInputs(os.Environ())
-			_, _, err := dialog.SyncBeforeShip(false, dialogTestInputs.Next())
+			_, _, err := dialog.SyncBeforeShip(false, dialogTestInputs.Value.Next())
 			return err
 		},
 	}
