@@ -98,31 +98,27 @@ func executePrepend(args []string, dryRun, verbose bool) error {
 }
 
 type prependData struct {
-	allBranches               gitdomain.BranchInfos
-	branchesSnapshot          gitdomain.BranchesSnapshot
-	branchesToSync            gitdomain.BranchInfos
-	config                    config.ValidatedConfig
-	dialogTestInputs          components.TestInputs
-	dryRun                    bool
-	hasOpenChanges            bool
-	initialBranch             gitdomain.LocalBranchName
-	newBranchParentCandidates gitdomain.LocalBranchNames
-	parentBranch              gitdomain.LocalBranchName
-	previousBranch            Option[gitdomain.LocalBranchName]
-	remotes                   gitdomain.Remotes
-	stashSize                 gitdomain.StashSize
-	targetBranch              gitdomain.LocalBranchName
+	allBranches         gitdomain.BranchInfos
+	branchesSnapshot    gitdomain.BranchesSnapshot
+	branchesToSync      gitdomain.BranchInfos
+	config              config.ValidatedConfig
+	dialogTestInputs    Mutable[components.TestInputs]
+	dryRun              bool
+	existingParent      gitdomain.LocalBranchName
+	hasOpenChanges      bool
+	initialBranch       gitdomain.LocalBranchName
+	newParentCandidates gitdomain.LocalBranchNames
+	previousBranch      Option[gitdomain.LocalBranchName]
+	remotes             gitdomain.Remotes
+	stashSize           gitdomain.StashSize
+	targetBranch        gitdomain.LocalBranchName
 }
 
-func emptyPrependData() prependData {
-	return prependData{} //exhaustruct:ignore
-}
-
-func determinePrependData(args []string, repo execute.OpenRepoResult, dryRun, verbose bool) (prependData, bool, error) {
+func determinePrependData(args []string, repo execute.OpenRepoResult, dryRun, verbose bool) (data prependData, exit bool, err error) {
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
 	repoStatus, err := repo.Git.RepoStatus(repo.Backend)
 	if err != nil {
-		return emptyPrependData(), false, err
+		return data, false, err
 	}
 	fc := execute.FailureCollector{}
 	branchesSnapshot, stashSize, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
@@ -143,21 +139,21 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, dryRun, ve
 		Verbose:               verbose,
 	})
 	if err != nil || exit {
-		return emptyPrependData(), exit, err
+		return data, exit, err
 	}
 	previousBranch := repo.Git.PreviouslyCheckedOutBranch(repo.Backend)
 	remotes := fc.Remotes(repo.Git.Remotes(repo.Backend))
 	targetBranch := gitdomain.NewLocalBranchName(args[0])
 	if branchesSnapshot.Branches.HasLocalBranch(targetBranch) {
-		return emptyPrependData(), false, fmt.Errorf(messages.BranchAlreadyExistsLocally, targetBranch)
+		return data, false, fmt.Errorf(messages.BranchAlreadyExistsLocally, targetBranch)
 	}
 	if branchesSnapshot.Branches.HasMatchingTrackingBranchFor(targetBranch) {
-		return emptyPrependData(), false, fmt.Errorf(messages.BranchAlreadyExistsRemotely, targetBranch)
+		return data, false, fmt.Errorf(messages.BranchAlreadyExistsRemotely, targetBranch)
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
 	initialBranch, hasInitialBranch := branchesSnapshot.Active.Get()
 	if !hasInitialBranch {
-		return emptyPrependData(), false, errors.New(messages.CurrentBranchCannotDetermine)
+		return data, false, errors.New(messages.CurrentBranchCannotDetermine)
 	}
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
@@ -172,72 +168,72 @@ func determinePrependData(args []string, repo execute.OpenRepoResult, dryRun, ve
 		Unvalidated:        repo.UnvalidatedConfig,
 	})
 	if err != nil || exit {
-		return emptyPrependData(), exit, err
+		return data, exit, err
 	}
 	branchNamesToSync := validatedConfig.Config.Lineage.BranchAndAncestors(initialBranch)
 	branchesToSync := fc.BranchInfos(branchesSnapshot.Branches.Select(branchNamesToSync...))
 	parent, hasParent := validatedConfig.Config.Lineage.Parent(initialBranch).Get()
 	if !hasParent {
-		return emptyPrependData(), false, fmt.Errorf(messages.SetParentNoFeatureBranch, branchesSnapshot.Active)
+		return data, false, fmt.Errorf(messages.SetParentNoFeatureBranch, branchesSnapshot.Active)
 	}
 	parentAndAncestors := validatedConfig.Config.Lineage.BranchAndAncestors(parent)
 	slices.Reverse(parentAndAncestors)
 	return prependData{
-		allBranches:               branchesSnapshot.Branches,
-		branchesSnapshot:          branchesSnapshot,
-		branchesToSync:            branchesToSync,
-		config:                    validatedConfig,
-		dialogTestInputs:          dialogTestInputs,
-		dryRun:                    dryRun,
-		hasOpenChanges:            repoStatus.OpenChanges,
-		initialBranch:             initialBranch,
-		newBranchParentCandidates: parentAndAncestors,
-		parentBranch:              parent,
-		previousBranch:            previousBranch,
-		remotes:                   remotes,
-		stashSize:                 stashSize,
-		targetBranch:              targetBranch,
+		allBranches:         branchesSnapshot.Branches,
+		branchesSnapshot:    branchesSnapshot,
+		branchesToSync:      branchesToSync,
+		config:              validatedConfig,
+		dialogTestInputs:    dialogTestInputs,
+		dryRun:              dryRun,
+		existingParent:      parent,
+		hasOpenChanges:      repoStatus.OpenChanges,
+		initialBranch:       initialBranch,
+		newParentCandidates: parentAndAncestors,
+		previousBranch:      previousBranch,
+		remotes:             remotes,
+		stashSize:           stashSize,
+		targetBranch:        targetBranch,
 	}, false, fc.Err
 }
 
 func prependProgram(data prependData) program.Program {
-	prog := program.Program{}
+	prog := NewMutable(&program.Program{})
 	for _, branchToSync := range data.branchesToSync {
 		sync.BranchProgram(branchToSync, sync.BranchProgramArgs{
 			BranchInfos:   data.allBranches,
 			Config:        data.config.Config,
 			InitialBranch: data.initialBranch,
-			Program:       &prog,
+			Program:       prog,
 			PushBranch:    true,
 			Remotes:       data.remotes,
 		})
 	}
-	prog.Add(&opcodes.CreateAndCheckoutBranchExistingParent{
-		Ancestors: data.newBranchParentCandidates,
+	prog.Value.Add(&opcodes.CreateAndCheckoutBranchExistingParent{
+		Ancestors: data.newParentCandidates,
 		Branch:    data.targetBranch,
 	})
 	// set the parent of the newly created branch
-	prog.Add(&opcodes.SetExistingParent{
+	prog.Value.Add(&opcodes.SetExistingParent{
 		Branch:    data.targetBranch,
-		Ancestors: data.newBranchParentCandidates,
+		Ancestors: data.newParentCandidates,
 	})
 	// set the parent of the branch prepended to
-	prog.Add(&opcodes.SetParentIfBranchExists{
+	prog.Value.Add(&opcodes.SetParentIfBranchExists{
 		Branch: data.initialBranch,
 		Parent: data.targetBranch,
 	})
 	if data.remotes.HasOrigin() && data.config.Config.ShouldPushNewBranches() && data.config.Config.IsOnline() {
-		prog.Add(&opcodes.CreateTrackingBranch{Branch: data.targetBranch})
+		prog.Value.Add(&opcodes.CreateTrackingBranch{Branch: data.targetBranch})
 	}
 	previousBranchCandidates := gitdomain.LocalBranchNames{}
 	if previousBranch, hasPreviousBranch := data.previousBranch.Get(); hasPreviousBranch {
 		previousBranchCandidates = append(previousBranchCandidates, previousBranch)
 	}
-	cmdhelpers.Wrap(&prog, cmdhelpers.WrapOptions{
+	cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
 		DryRun:                   data.dryRun,
 		RunInGitRoot:             true,
 		StashOpenChanges:         data.hasOpenChanges,
 		PreviousBranchCandidates: previousBranchCandidates,
 	})
-	return prog
+	return prog.Get()
 }
