@@ -113,7 +113,7 @@ type proposeData struct {
 	branchesToSync   gitdomain.BranchInfos
 	config           config.ValidatedConfig
 	connector        Option[hostingdomain.Connector]
-	dialogTestInputs components.TestInputs
+	dialogTestInputs Mutable[components.TestInputs]
 	dryRun           bool
 	hasOpenChanges   bool
 	initialBranch    gitdomain.LocalBranchName
@@ -122,15 +122,11 @@ type proposeData struct {
 	stashSize        gitdomain.StashSize
 }
 
-func emptyProposeData() proposeData {
-	return proposeData{} //exhaustruct:ignore
-}
-
-func determineProposeData(repo execute.OpenRepoResult, dryRun, verbose bool) (proposeData, bool, error) {
+func determineProposeData(repo execute.OpenRepoResult, dryRun, verbose bool) (data proposeData, exit bool, err error) {
 	dialogTestInputs := components.LoadTestInputs(os.Environ())
 	repoStatus, err := repo.Git.RepoStatus(repo.Backend)
 	if err != nil {
-		return emptyProposeData(), false, err
+		return data, false, err
 	}
 	branchesSnapshot, stashSize, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
 		Backend:               repo.Backend,
@@ -150,17 +146,17 @@ func determineProposeData(repo execute.OpenRepoResult, dryRun, verbose bool) (pr
 		Verbose:               verbose,
 	})
 	if err != nil || exit {
-		return emptyProposeData(), exit, err
+		return data, exit, err
 	}
 	previousBranch := repo.Git.PreviouslyCheckedOutBranch(repo.Backend)
 	remotes, err := repo.Git.Remotes(repo.Backend)
 	if err != nil {
-		return emptyProposeData(), false, err
+		return data, false, err
 	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
 	initialBranch, hasInitialBranch := branchesSnapshot.Active.Get()
 	if !hasInitialBranch {
-		return emptyProposeData(), false, errors.New(messages.CurrentBranchCannotDetermine)
+		return data, false, errors.New(messages.CurrentBranchCannotDetermine)
 	}
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
@@ -175,7 +171,7 @@ func determineProposeData(repo execute.OpenRepoResult, dryRun, verbose bool) (pr
 		Unvalidated:        repo.UnvalidatedConfig,
 	})
 	if err != nil || exit {
-		return emptyProposeData(), exit, err
+		return data, exit, err
 	}
 	var connector Option[hostingdomain.Connector]
 	if originURL, hasOriginURL := validatedConfig.OriginURL().Get(); hasOriginURL {
@@ -186,11 +182,11 @@ func determineProposeData(repo execute.OpenRepoResult, dryRun, verbose bool) (pr
 			OriginURL:       originURL,
 		})
 		if err != nil {
-			return emptyProposeData(), false, err
+			return data, false, err
 		}
 	}
 	if connector.IsNone() {
-		return emptyProposeData(), false, hostingdomain.UnsupportedServiceError()
+		return data, false, hostingdomain.UnsupportedServiceError()
 	}
 	branchNamesToSync := validatedConfig.Config.Lineage.BranchAndAncestors(initialBranch)
 	branchesToSync, err := branchesSnapshot.Branches.Select(branchNamesToSync...)
@@ -211,14 +207,14 @@ func determineProposeData(repo execute.OpenRepoResult, dryRun, verbose bool) (pr
 }
 
 func proposeProgram(data proposeData) program.Program {
-	prog := program.Program{}
+	prog := NewMutable(&program.Program{})
 	for _, branch := range data.branchesToSync {
 		sync.BranchProgram(branch, sync.BranchProgramArgs{
 			BranchInfos:   data.allBranches,
 			Config:        data.config.Config,
 			InitialBranch: data.initialBranch,
 			Remotes:       data.remotes,
-			Program:       &prog,
+			Program:       prog,
 			PushBranch:    true,
 		})
 	}
@@ -226,17 +222,17 @@ func proposeProgram(data proposeData) program.Program {
 	if previousBranch, hasPreviousBranch := data.previousBranch.Get(); hasPreviousBranch {
 		previousBranchCandidates = append(previousBranchCandidates, previousBranch)
 	}
-	cmdhelpers.Wrap(&prog, cmdhelpers.WrapOptions{
+	cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
 		DryRun:                   data.dryRun,
 		RunInGitRoot:             true,
 		StashOpenChanges:         data.hasOpenChanges,
 		PreviousBranchCandidates: previousBranchCandidates,
 	})
-	prog.Add(&opcodes.CreateProposal{
+	prog.Value.Add(&opcodes.CreateProposal{
 		Branch:     data.initialBranch,
 		MainBranch: data.config.Config.MainBranch,
 	})
-	return prog
+	return prog.Get()
 }
 
 func validateProposeData(data proposeData) error {
