@@ -1,6 +1,9 @@
 package configdomain
 
 import (
+	"cmp"
+	"slices"
+
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	. "github.com/git-town/git-town/v14/src/gohacks/prelude"
 	"github.com/git-town/git-town/v14/src/gohacks/slice"
@@ -10,14 +13,27 @@ import (
 // Lineage encapsulates all data and functionality around parent branches.
 // branch --> its parent
 // Lineage only contains branches that have ancestors.
-type Lineage map[gitdomain.LocalBranchName]gitdomain.LocalBranchName
+type Lineage struct {
+	data map[gitdomain.LocalBranchName]gitdomain.LocalBranchName
+}
+
+func NewLineage() Lineage {
+	return Lineage{
+		data: make(map[gitdomain.LocalBranchName]gitdomain.LocalBranchName),
+	}
+}
+
+func (self *Lineage) Add(branch, parent gitdomain.LocalBranchName) {
+	self.initializeIfNeeded()
+	self.data[branch] = parent
+}
 
 // Ancestors provides the names of all parent branches of the branch with the given name.
 func (self Lineage) Ancestors(branch gitdomain.LocalBranchName) gitdomain.LocalBranchNames {
 	current := branch
 	result := gitdomain.LocalBranchNames{}
 	for {
-		parent, found := self[current]
+		parent, found := self.data[current]
 		if !found {
 			return result
 		}
@@ -28,19 +44,11 @@ func (self Lineage) Ancestors(branch gitdomain.LocalBranchName) gitdomain.LocalB
 
 // AncestorsWithoutRoot provides the names of all parent branches of the branch with the given name, excluding the root perennial branch.
 func (self Lineage) AncestorsWithoutRoot(branch gitdomain.LocalBranchName) gitdomain.LocalBranchNames {
-	current := branch
-	result := gitdomain.LocalBranchNames{}
-	for {
-		parent, found := self[current]
-		if !found {
-			if len(result) == 0 {
-				return result
-			}
-			return result[1:]
-		}
-		result.Prepend(parent)
-		current = parent
+	ancestors := self.Ancestors(branch)
+	if len(ancestors) > 0 {
+		return ancestors[1:]
 	}
+	return ancestors
 }
 
 // BranchAndAncestors provides the full ancestry for the branch with the given name,
@@ -60,7 +68,14 @@ func (self Lineage) BranchLineageWithoutRoot(branch gitdomain.LocalBranchName) g
 
 // BranchNames provides the names of all branches in this Lineage, sorted alphabetically.
 func (self Lineage) BranchNames() gitdomain.LocalBranchNames {
-	result := gitdomain.LocalBranchNames(maps.Keys(self))
+	result := gitdomain.LocalBranchNames(maps.Keys(self.data))
+	result.Sort()
+	return result
+}
+
+// provides all branches for which the parent is known
+func (self Lineage) Branches() gitdomain.LocalBranchNames {
+	var result gitdomain.LocalBranchNames = maps.Keys(self.data)
 	result.Sort()
 	return result
 }
@@ -78,7 +93,7 @@ func (self Lineage) BranchesAndAncestors(branchNames gitdomain.LocalBranchNames)
 // Children provides the names of all branches that have the given branch as their parent.
 func (self Lineage) Children(branch gitdomain.LocalBranchName) gitdomain.LocalBranchNames {
 	result := gitdomain.LocalBranchNames{}
-	for child, parent := range self {
+	for child, parent := range self.data {
 		if parent == branch {
 			result = append(result, child)
 		}
@@ -97,9 +112,23 @@ func (self Lineage) Descendants(branch gitdomain.LocalBranchName) gitdomain.Loca
 	return result
 }
 
+func (self Lineage) Entries() []LineageEntry {
+	result := make([]LineageEntry, 0, self.Len())
+	for branch, parent := range self.data {
+		result = append(result, LineageEntry{
+			Child:  branch,
+			Parent: parent,
+		})
+	}
+	slices.SortFunc(result, func(a, b LineageEntry) int {
+		return cmp.Compare(a.Child, b.Child)
+	})
+	return result
+}
+
 // HasParents returns whether or not the given branch has at least one parent.
 func (self Lineage) HasParents(branch gitdomain.LocalBranchName) bool {
-	for child := range self {
+	for child := range self.data {
 		if child == branch {
 			return true
 		}
@@ -109,22 +138,21 @@ func (self Lineage) HasParents(branch gitdomain.LocalBranchName) bool {
 
 // IsAncestor indicates whether the given branch is an ancestor of the other given branch.
 func (self Lineage) IsAncestor(ancestor, other gitdomain.LocalBranchName) bool {
-	current := other
-	for {
-		parent, found := self[current]
-		if !found {
-			return false
-		}
-		if parent == ancestor {
-			return true
-		}
-		current = parent
-	}
+	ancestors := self.Ancestors(other)
+	return ancestors.Contains(ancestor)
+}
+
+func (self Lineage) IsEmpty() bool {
+	return self.data == nil || self.Len() == 0
+}
+
+func (self Lineage) Len() int {
+	return len(self.data)
 }
 
 // OrderHierarchically provides the given branches sorted so that ancestor branches come before their descendants.
 func (self Lineage) OrderHierarchically(branches gitdomain.LocalBranchNames) gitdomain.LocalBranchNames {
-	result := make(gitdomain.LocalBranchNames, 0, len(self))
+	result := make(gitdomain.LocalBranchNames, 0, len(self.data))
 	for _, root := range self.Roots() {
 		self.addChildrenHierarchically(&result, root, branches)
 	}
@@ -134,7 +162,7 @@ func (self Lineage) OrderHierarchically(branches gitdomain.LocalBranchNames) git
 
 // Parent provides the name of the parent branch for the given branch or nil if the branch has no parent.
 func (self Lineage) Parent(branch gitdomain.LocalBranchName) Option[gitdomain.LocalBranchName] {
-	for child, parent := range self {
+	for child, parent := range self.data {
 		if child == branch {
 			return Some(parent)
 		}
@@ -147,19 +175,19 @@ func (self Lineage) RemoveBranch(branch gitdomain.LocalBranchName) {
 	parent, hasParent := self.Parent(branch).Get()
 	for _, childName := range self.Children(branch) {
 		if hasParent {
-			self[childName] = parent
+			self.data[childName] = parent
 		} else {
-			delete(self, childName)
+			delete(self.data, childName)
 		}
 	}
-	delete(self, branch)
+	delete(self.data, branch)
 }
 
 // Roots provides the branches with children and no parents.
 func (self Lineage) Roots() gitdomain.LocalBranchNames {
 	roots := gitdomain.LocalBranchNames{}
-	for _, parent := range self {
-		_, found := self[parent]
+	for _, parent := range self.data {
+		_, found := self.data[parent]
 		if !found && !slice.Contains(roots, parent) {
 			roots = append(roots, parent)
 		}
@@ -176,3 +204,9 @@ func (self Lineage) addChildrenHierarchically(result *gitdomain.LocalBranchNames
 		self.addChildrenHierarchically(result, child, allBranches)
 	}
 }
+
+func (self *Lineage) initializeIfNeeded() {
+	if self.data == nil {
+		self.data = make(map[gitdomain.LocalBranchName]gitdomain.LocalBranchName)
+	}
+}
