@@ -785,8 +785,7 @@ func ParseVerboseBranchesOutput(output string) (gitdomain.BranchInfos, Option[gi
 			})
 		default:
 			remoteBranchName := gitdomain.NewRemoteBranchName(strings.TrimPrefix(branchName, "remotes/"))
-			existingBranchWithTracking := result.FindByRemoteName(remoteBranchName)
-			if existingBranchWithTracking != nil {
+			if existingBranchWithTracking, hasExistingBranchWithTracking := result.FindByRemoteName(remoteBranchName).Get(); hasExistingBranchWithTracking {
 				existingBranchWithTracking.RemoteSHA = Some(sha)
 			} else {
 				result = append(result, gitdomain.BranchInfo{
