@@ -6,7 +6,7 @@ import "github.com/git-town/git-town/v14/src/messages"
 // The zero value is an empty cache.
 type Cache[T any] struct {
 	initialized bool
-	value       T
+	value       *T
 }
 
 // Initialized indicates if we have a current branch.
@@ -20,13 +20,13 @@ func (c *Cache[T]) Invalidate() {
 }
 
 // Set allows collaborators to signal when the current branch has changed.
-func (c *Cache[T]) Set(newValue T) {
+func (c *Cache[T]) Set(newValue *T) {
 	c.value = newValue
 	c.initialized = true
 }
 
 // Value provides the current value.
-func (c *Cache[T]) Value() T {
+func (c *Cache[T]) Value() *T {
 	if !c.initialized {
 		panic(messages.CacheUnitialized)
 	}
