@@ -17,8 +17,8 @@ func TestConnector(t *testing.T) {
 
 	t.Run("DefaultProposalMessage", func(t *testing.T) {
 		t.Parallel()
-		connector := github.Connector{} //nolint:exhaustruct
-		give := hostingdomain.Proposal{ //nolint:exhaustruct
+		connector := github.Connector{}
+		give := hostingdomain.Proposal{
 			Number: 1,
 			Title:  "my title",
 		}
@@ -52,16 +52,16 @@ func TestConnector(t *testing.T) {
 		}
 		for name, tt := range tests {
 			t.Run(name, func(t *testing.T) {
+				main := gitdomain.NewLocalBranchName("main")
 				connector := github.Connector{
-					Config: hostingdomain.Config{
+					Data: hostingdomain.Data{
 						Hostname:     "github.com",
 						Organization: "organization",
 						Repository:   "repo",
 					},
-					APIToken:   "apiToken",
-					MainBranch: gitdomain.NewLocalBranchName("main"),
+					APIToken: configdomain.NewGitHubTokenOption("apiToken"),
 				}
-				have, err := connector.NewProposalURL(tt.branch, tt.parent)
+				have, err := connector.NewProposalURL(tt.branch, tt.parent, main)
 				must.NoError(t, err)
 				must.EqOp(t, tt.want, have)
 			})
@@ -70,8 +70,8 @@ func TestConnector(t *testing.T) {
 
 	t.Run("RepositoryURL", func(t *testing.T) {
 		t.Parallel()
-		connector := github.Connector{ //nolint:exhaustruct
-			Config: hostingdomain.Config{
+		connector := github.Connector{
+			Data: hostingdomain.Data{
 				Hostname:     "github.com",
 				Organization: "organization",
 				Repository:   "repo",
@@ -88,37 +88,37 @@ func TestNewConnector(t *testing.T) {
 
 	t.Run("GitHub SaaS", func(t *testing.T) {
 		t.Parallel()
+		originURL, has := giturl.Parse("git@github.com:git-town/docs.git").Get()
+		must.True(t, has)
 		have, err := github.NewConnector(github.NewConnectorArgs{
-			APIToken:        "apiToken",
-			HostingPlatform: configdomain.HostingPlatformNone,
-			Log:             print.Logger{},
-			MainBranch:      gitdomain.NewLocalBranchName("mainBranch"),
-			OriginURL:       giturl.Parse("git@github.com:git-town/docs.git"),
+			APIToken:  configdomain.NewGitHubTokenOption("apiToken"),
+			Log:       print.Logger{},
+			OriginURL: originURL,
 		})
 		must.NoError(t, err)
-		wantConfig := hostingdomain.Config{
+		wantConfig := hostingdomain.Data{
 			Hostname:     "github.com",
 			Organization: "git-town",
 			Repository:   "docs",
 		}
-		must.EqOp(t, wantConfig, have.Config)
+		must.EqOp(t, wantConfig, have.Data)
 	})
 
-	t.Run("hosted service type provided manually", func(t *testing.T) {
+	t.Run("custom URL", func(t *testing.T) {
 		t.Parallel()
+		originURL, has := giturl.Parse("git@custom-url.com:git-town/docs.git").Get()
+		must.True(t, has)
 		have, err := github.NewConnector(github.NewConnectorArgs{
-			APIToken:        "apiToken",
-			HostingPlatform: configdomain.HostingPlatformGitHub,
-			Log:             print.Logger{},
-			MainBranch:      gitdomain.NewLocalBranchName("mainBranch"),
-			OriginURL:       giturl.Parse("git@custom-url.com:git-town/docs.git"),
+			APIToken:  configdomain.NewGitHubTokenOption("apiToken"),
+			Log:       print.Logger{},
+			OriginURL: originURL,
 		})
 		must.NoError(t, err)
-		wantConfig := hostingdomain.Config{
+		wantConfig := hostingdomain.Data{
 			Hostname:     "custom-url.com",
 			Organization: "git-town",
 			Repository:   "docs",
 		}
-		must.EqOp(t, wantConfig, have.Config)
+		must.EqOp(t, wantConfig, have.Data)
 	})
 }
