@@ -2,9 +2,7 @@ package subshell_test
 
 import (
 	"errors"
-	"os"
 	"os/exec"
-	"path/filepath"
 	"testing"
 
 	"github.com/git-town/git-town/v14/src/gohacks"
@@ -20,7 +18,7 @@ func TestBackendRunner(t *testing.T) {
 		t.Parallel()
 		t.Run("happy path", func(t *testing.T) {
 			tmpDir := t.TempDir()
-			runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: gohacks.NewCounter()}
+			runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: NewMutable(new(gohacks.Counter))}
 			output, err := runner.Query("echo", "hello", "world  ")
 			must.NoError(t, err)
 			must.EqOp(t, "hello world  \n", output)
@@ -29,7 +27,7 @@ func TestBackendRunner(t *testing.T) {
 		t.Run("unknown executable", func(t *testing.T) {
 			t.Parallel()
 			tmpDir := t.TempDir()
-			runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: gohacks.NewCounter()}
+			runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: NewMutable(new(gohacks.Counter))}
 			err := runner.Run("zonk")
 			must.Error(t, err)
 			var execError *exec.Error
@@ -39,7 +37,7 @@ func TestBackendRunner(t *testing.T) {
 		t.Run("non-zero exit code", func(t *testing.T) {
 			t.Parallel()
 			tmpDir := t.TempDir()
-			runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: gohacks.NewCounter()}
+			runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: NewMutable(new(gohacks.Counter))}
 			err := runner.Run("bash", "-c", "echo hi && exit 2")
 			expectedError := `
 ----------------------------------------
@@ -60,26 +58,10 @@ OUTPUT END
 		t.Parallel()
 		t.Run("trims whitespace", func(t *testing.T) {
 			tmpDir := t.TempDir()
-			runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: gohacks.NewCounter()}
+			runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: NewMutable(new(gohacks.Counter))}
 			output, err := runner.QueryTrim("echo", "hello", "world  ")
 			must.NoError(t, err)
 			must.EqOp(t, "hello world", output)
 		})
 	})
-
-	t.Run("RunMany", func(t *testing.T) {
-		t.Parallel()
-		tmpDir := t.TempDir()
-		runner := subshell.BackendRunner{Dir: Some(tmpDir), Verbose: false, CommandsCounter: gohacks.NewCounter()}
-		err := runner.RunMany([][]string{
-			{"mkdir", "tmp"},
-			{"touch", "tmp/first"},
-			{"touch", "tmp/second"},
-		})
-		must.NoError(t, err)
-		entries, err := os.ReadDir(filepath.Join(tmpDir, "tmp"))
-		must.NoError(t, err)
-		must.EqOp(t, "first", entries[0].Name())
-		must.EqOp(t, "second", entries[1].Name())
-	})
 }
