@@ -5,14 +5,14 @@ import (
 
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	"github.com/git-town/git-town/v14/src/gohacks"
-	"github.com/git-town/git-town/v14/src/messages"
+	. "github.com/git-town/git-town/v14/src/gohacks/prelude"
 )
 
 // FrontendDryRunner prints the given shell commands to the CLI as if they were executed
 // but does not execute them.
 type FrontendDryRunner struct {
 	Backend          gitdomain.Querier
-	CommandsCounter  gohacks.Counter
+	CommandsCounter  Mutable[gohacks.Counter]
 	GetCurrentBranch GetCurrentBranchFunc
 	OmitBranchNames  bool
 	PrintCommands    bool
@@ -36,16 +36,3 @@ func (self *FrontendDryRunner) Run(executable string, args ...string) error {
 	}
 	return nil
 }
-
-// RunMany runs all given commands in current directory.
-// Commands are provided as a list of argv-style strings.
-// Failed commands abort immediately with the encountered error.
-func (self *FrontendDryRunner) RunMany(commands [][]string) error {
-	for _, argv := range commands {
-		err := self.Run(argv[0], argv[1:]...)
-		if err != nil {
-			return fmt.Errorf(messages.RunCommandProblem, argv, err)
-		}
-	}
-	return nil
-}
