@@ -12,13 +12,13 @@ import (
 	"github.com/git-town/git-town/v14/src/cli/colors"
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	"github.com/git-town/git-town/v14/src/gohacks"
-	"github.com/git-town/git-town/v14/src/messages"
+	. "github.com/git-town/git-town/v14/src/gohacks/prelude"
 )
 
 // FrontendRunner executes frontend shell commands.
 type FrontendRunner struct {
 	Backend          gitdomain.Querier
-	CommandsCounter  gohacks.Counter
+	CommandsCounter  Mutable[gohacks.Counter]
 	GetCurrentBranch GetCurrentBranchFunc
 	OmitBranchNames  bool
 	PrintCommands    bool
@@ -56,7 +56,7 @@ func PrintCommand(branch gitdomain.LocalBranchName, omitBranch bool, cmd string,
 
 // Run runs the given command in this ShellRunner's directory.
 func (self *FrontendRunner) Run(cmd string, args ...string) (err error) {
-	self.CommandsCounter.Register()
+	self.CommandsCounter.Value.Inc()
 	var branchName gitdomain.LocalBranchName
 	if !self.OmitBranchNames {
 		branchName, err = self.GetCurrentBranch(self.Backend)
@@ -94,16 +94,3 @@ func (self *FrontendRunner) Run(cmd string, args ...string) (err error) {
 	}()
 	return subProcess.Wait()
 }
-
-// RunMany runs all given commands in current directory.
-// Commands are provided as a list of argv-style strings.
-// Failed commands abort immediately with the encountered error.
-func (self *FrontendRunner) RunMany(commands [][]string) error {
-	for _, argv := range commands {
-		err := self.Run(argv[0], argv[1:]...)
-		if err != nil {
-			return fmt.Errorf(messages.RunCommandProblem, argv, err)
-		}
-	}
-	return nil
-}
