@@ -8,8 +8,8 @@ import (
 )
 
 // PerennialBranchProgram adds the opcodes to sync the observed branch with the given name.
-func ObservedBranchProgram(branch Option[gitdomain.RemoteBranchName], prog *program.Program) {
+func ObservedBranchProgram(branch Option[gitdomain.RemoteBranchName], prog Mutable[program.Program]) {
 	if remoteBranch, hasRemoteBranch := branch.Get(); hasRemoteBranch {
-		prog.Add(&opcodes.RebaseBranch{Branch: remoteBranch.BranchName()})
+		prog.Value.Add(&opcodes.RebaseBranch{Branch: remoteBranch.BranchName()})
 	}
 }
