@@ -12,8 +12,8 @@ func PerennialBranchProgram(branch gitdomain.BranchInfo, args BranchProgramArgs)
 	}
 	if localBranch, hasLocalBranch := branch.LocalName.Get(); hasLocalBranch {
 		if localBranch == args.Config.MainBranch && args.Remotes.HasUpstream() && args.Config.SyncUpstream.Bool() {
-			args.Program.Add(&opcodes.FetchUpstream{Branch: args.Config.MainBranch})
-			args.Program.Add(&opcodes.RebaseBranch{Branch: gitdomain.NewBranchName("upstream/" + args.Config.MainBranch.String())})
+			args.Program.Value.Add(&opcodes.FetchUpstream{Branch: args.Config.MainBranch})
+			args.Program.Value.Add(&opcodes.RebaseBranch{Branch: gitdomain.NewBranchName("upstream/" + args.Config.MainBranch.String())})
 		}
 	}
 }
