@@ -28,21 +28,6 @@ type BranchChanges struct {
 	RemoteRemoved RemoteBranchesSHAs
 }
 
-// EmptyBranchChanges provides a properly initialized empty Changes instance.
-func EmptyBranchChanges() BranchChanges {
-	return BranchChanges{
-		InconsistentlyChanged: undodomain.InconsistentChanges{},
-		LocalAdded:            gitdomain.LocalBranchNames{},
-		LocalChanged:          LocalBranchChange{},
-		LocalRemoved:          LocalBranchesSHAs{},
-		OmniChanged:           LocalBranchChange{},
-		OmniRemoved:           LocalBranchesSHAs{},
-		RemoteAdded:           gitdomain.RemoteBranchNames{},
-		RemoteChanged:         map[gitdomain.RemoteBranchName]undodomain.Change[gitdomain.SHA]{},
-		RemoteRemoved:         map[gitdomain.RemoteBranchName]gitdomain.SHA{},
-	}
-}
-
 // uncomment when debugging the undo logic
 // func (self BranchChanges) String() string {
 // 	s := strings.Builder{}
@@ -63,8 +48,6 @@ func EmptyBranchChanges() BranchChanges {
 // 	s.WriteString(strings.Join(self.OmniRemoved.BranchNames().Strings(), ", "))
 // 	s.WriteString("\n  OmniChanged: ")
 // 	s.WriteString(strings.Join(self.OmniChanged.BranchNames().Strings(), ", "))
-// 	s.WriteString("\n  InconsistentlyChanged: ")
-// 	s.WriteString(strings.Join(self.InconsistentlyChanged.BranchNames().Strings(), ", "))
 // 	s.WriteRune('\n')
 // 	return s.String()
 // }
@@ -103,28 +86,33 @@ func (self BranchChanges) UndoProgram(args BranchChangesUndoProgramArgs) program
 
 	// reset inconsintently changed perennial branches
 	for _, inconsistentlyChangedPerennial := range inconsistentlyChangedPerennials {
-		if inconsistentlyChangedPerennial.After.IsOmniBranch() {
-			if slice.Contains(args.UndoablePerennialCommits, inconsistentlyChangedPerennial.After.LocalSHA) {
-				result.Add(&opcodes.Checkout{Branch: inconsistentlyChangedPerennial.Before.LocalName})
-				result.Add(&opcodes.RevertCommit{SHA: inconsistentlyChangedPerennial.After.LocalSHA})
-				result.Add(&opcodes.PushCurrentBranch{CurrentBranch: inconsistentlyChangedPerennial.After.LocalName})
+		if isOmni, branchName, afterSHA := inconsistentlyChangedPerennial.After.IsOmniBranch(); isOmni {
+			if slice.Contains(args.UndoablePerennialCommits, afterSHA) {
+				result.Add(&opcodes.Checkout{Branch: branchName})
+				result.Add(&opcodes.RevertCommit{SHA: afterSHA})
+				result.Add(&opcodes.PushCurrentBranch{CurrentBranch: branchName})
 			}
 		}
 	}
 
 	// reset inconsintently changed feature branches
 	for _, inconsistentChange := range inconsistentChangedFeatures {
-		result.Add(&opcodes.Checkout{Branch: inconsistentChange.Before.LocalName})
-		result.Add(&opcodes.ResetCurrentBranchToSHA{
-			MustHaveSHA: inconsistentChange.After.LocalSHA,
-			SetToSHA:    inconsistentChange.Before.LocalSHA,
-			Hard:        true,
-		})
-		result.Add(&opcodes.ResetRemoteBranchToSHA{
-			Branch:      inconsistentChange.Before.RemoteName,
-			MustHaveSHA: inconsistentChange.After.RemoteSHA,
-			SetToSHA:    inconsistentChange.Before.RemoteSHA,
-		})
+		hasBeforeLocal, beforeLocalName, beforeLocalSHA := inconsistentChange.Before.GetLocal()
+		hasBeforeRemote, beforeRemoteName, beforeRemoteSHA := inconsistentChange.Before.GetRemote()
+		hasAfterSHAs, afterLocalSHA, afterRemoteSHA := inconsistentChange.After.GetSHAs()
+		if hasBeforeLocal && hasBeforeRemote && hasAfterSHAs {
+			result.Add(&opcodes.Checkout{Branch: beforeLocalName})
+			result.Add(&opcodes.ResetCurrentBranchToSHA{
+				MustHaveSHA: afterLocalSHA,
+				SetToSHA:    beforeLocalSHA,
+				Hard:        true,
+			})
+			result.Add(&opcodes.ResetRemoteBranchToSHA{
+				Branch:      beforeRemoteName,
+				MustHaveSHA: afterRemoteSHA,
+				SetToSHA:    beforeRemoteSHA,
+			})
+		}
 	}
 
 	// remove remotely added branches
@@ -192,7 +180,7 @@ func (self BranchChanges) UndoProgram(args BranchChangesUndoProgramArgs) program
 
 type BranchChangesUndoProgramArgs struct {
 	BeginBranch              gitdomain.LocalBranchName
-	Config                   *configdomain.FullConfig
+	Config                   configdomain.ValidatedConfig
 	EndBranch                gitdomain.LocalBranchName
 	UndoablePerennialCommits []gitdomain.SHA
 }
