@@ -7,17 +7,18 @@ import (
 	"github.com/git-town/git-town/v14/src/config/configdomain"
 	"github.com/git-town/git-town/v14/src/git"
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	. "github.com/git-town/git-town/v14/src/gohacks/prelude"
 )
 
 func Config(args ConfigArgs) (config.ValidatedConfig, bool, error) {
 	// check Git user data
-	gitUserEmail, gitUserName, err := GitUser(*args.Unvalidated.Config)
+	gitUserEmail, gitUserName, err := GitUser(args.Unvalidated.Config.Get())
 	if err != nil {
 		return config.EmptyValidatedConfig(), false, err
 	}
 
 	// enter and save main and perennials
-	mainBranch, hasMain := args.Unvalidated.Config.MainBranch.Get()
+	mainBranch, hasMain := args.Unvalidated.Config.Value.MainBranch.Get()
 	if !hasMain {
 		validatedMain, additionalPerennials, aborted, err := dialog.MainAndPerennials(dialog.MainAndPerennialsArgs{
 			Backend:               args.Backend,
@@ -25,8 +26,8 @@ func Config(args ConfigArgs) (config.ValidatedConfig, bool, error) {
 			GetDefaultBranch:      args.Git.DefaultBranch,
 			HasConfigFile:         args.Unvalidated.ConfigFile.IsSome(),
 			LocalBranches:         args.LocalBranches,
-			UnvalidatedMain:       args.Unvalidated.Config.MainBranch,
-			UnvalidatedPerennials: args.Unvalidated.Config.PerennialBranches,
+			UnvalidatedMain:       args.Unvalidated.Config.Value.MainBranch,
+			UnvalidatedPerennials: args.Unvalidated.Config.Value.PerennialBranches,
 		})
 		if err != nil || aborted {
 			return config.EmptyValidatedConfig(), aborted, err
@@ -36,7 +37,7 @@ func Config(args ConfigArgs) (config.ValidatedConfig, bool, error) {
 			return config.EmptyValidatedConfig(), false, err
 		}
 		if len(additionalPerennials) > 0 {
-			newPerennials := append(args.Unvalidated.Config.PerennialBranches, additionalPerennials...)
+			newPerennials := append(args.Unvalidated.Config.Value.PerennialBranches, additionalPerennials...)
 			if err = args.Unvalidated.SetPerennialBranches(newPerennials); err != nil {
 				return config.EmptyValidatedConfig(), false, err
 			}
@@ -46,7 +47,7 @@ func Config(args ConfigArgs) (config.ValidatedConfig, bool, error) {
 	// enter and save missing parent branches
 	additionalLineage, additionalPerennials, exit, err := dialog.Lineage(dialog.LineageArgs{
 		BranchesToVerify: args.BranchesToValidate,
-		Config:           *args.Unvalidated.Config,
+		Config:           args.Unvalidated.Config.Get(),
 		DefaultChoice:    mainBranch,
 		DialogTestInputs: args.TestInputs,
 		LocalBranches:    args.LocalBranches,
@@ -55,13 +56,13 @@ func Config(args ConfigArgs) (config.ValidatedConfig, bool, error) {
 	if err != nil || exit {
 		return config.EmptyValidatedConfig(), exit, err
 	}
-	for branch, parent := range additionalLineage {
-		if err = args.Unvalidated.SetParent(branch, parent); err != nil {
+	for _, entry := range additionalLineage.Entries() {
+		if err = args.Unvalidated.SetParent(entry.Child, entry.Parent); err != nil {
 			return config.EmptyValidatedConfig(), false, err
 		}
 	}
 	if len(additionalPerennials) > 0 {
-		newPerennials := append(args.Unvalidated.Config.PerennialBranches, additionalPerennials...)
+		newPerennials := append(args.Unvalidated.Config.Value.PerennialBranches, additionalPerennials...)
 		if err = args.Unvalidated.SetPerennialBranches(newPerennials); err != nil {
 			return config.EmptyValidatedConfig(), false, err
 		}
@@ -70,7 +71,7 @@ func Config(args ConfigArgs) (config.ValidatedConfig, bool, error) {
 	// create validated configuration
 	validatedConfig := config.ValidatedConfig{
 		Config: configdomain.ValidatedConfig{
-			UnvalidatedConfig: args.Unvalidated.Config,
+			UnvalidatedConfig: args.Unvalidated.Config.Value,
 			GitUserEmail:      gitUserEmail,
 			GitUserName:       gitUserName,
 			MainBranch:        mainBranch,
@@ -85,11 +86,11 @@ type ConfigArgs struct {
 	Backend            gitdomain.RunnerQuerier
 	BranchesSnapshot   gitdomain.BranchesSnapshot
 	BranchesToValidate gitdomain.LocalBranchNames
-	DialogTestInputs   components.TestInputs
+	DialogTestInputs   Mutable[components.TestInputs]
 	Frontend           gitdomain.Runner
 	Git                git.Commands
 	LocalBranches      gitdomain.LocalBranchNames
 	RepoStatus         gitdomain.RepoStatus
-	TestInputs         components.TestInputs
+	TestInputs         Mutable[components.TestInputs]
 	Unvalidated        config.UnvalidatedConfig
 }
