@@ -46,10 +46,10 @@ func Execute(args ExecuteArgs) error {
 
 type ExecuteArgs struct {
 	Backend                 gitdomain.RunnerQuerier
-	CommandsCounter         gohacks.Counter
+	CommandsCounter         Mutable[gohacks.Counter]
 	Config                  config.ValidatedConfig
 	Connector               Option[hostingdomain.Connector]
-	DialogTestInputs        components.TestInputs
+	DialogTestInputs        Mutable[components.TestInputs]
 	FinalMessages           stringslice.Collector
 	Frontend                gitdomain.Runner
 	Git                     git.Commands
