@@ -7,7 +7,10 @@ import (
 	"github.com/git-town/git-town/v14/src/cli/dialog/components"
 	"github.com/git-town/git-town/v14/src/config"
 	"github.com/git-town/git-town/v14/src/git"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	. "github.com/git-town/git-town/v14/src/gohacks/prelude"
 	"github.com/git-town/git-town/v14/src/gohacks/stringslice"
+	"github.com/git-town/git-town/v14/src/hosting/hostingdomain"
 	"github.com/git-town/git-town/v14/src/vm/program"
 	"github.com/git-town/git-town/v14/src/vm/shared"
 )
@@ -17,10 +20,11 @@ func Execute(args ExecuteArgs) {
 		err := opcode.Run(shared.RunArgs{
 			Backend:                         args.Backend,
 			Config:                          args.Config,
-			Connector:                       nil,
+			Connector:                       None[hostingdomain.Connector](),
 			DialogTestInputs:                components.NewTestInputs(),
 			FinalMessages:                   args.FinalMessages,
 			Frontend:                        args.Frontend,
+			Git:                             args.Git,
 			PrependOpcodes:                  nil,
 			RegisterUndoablePerennialCommit: nil,
 			UpdateInitialBranchLocalSHA:     nil,
@@ -32,9 +36,10 @@ func Execute(args ExecuteArgs) {
 }
 
 type ExecuteArgs struct {
-	Backend       git.BackendCommands
+	Backend       gitdomain.RunnerQuerier
 	Config        config.ValidatedConfig
 	FinalMessages stringslice.Collector
-	Frontend      git.FrontendCommands
+	Frontend      gitdomain.Runner
+	Git           git.Commands
 	Prog          program.Program
 }
