@@ -7,10 +7,10 @@ import (
 
 // AddToPerennialBranches adds the branch with the given name as a perennial branch.
 type AddToPerennialBranches struct {
-	Branch gitdomain.LocalBranchName
-	undeclaredOpcodeMethods
+	Branch                  gitdomain.LocalBranchName
+	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
 func (self *AddToPerennialBranches) Run(args shared.RunArgs) error {
-	return args.Runner.Config.AddToPerennialBranches(self.Branch)
+	return args.Config.AddToPerennialBranches(self.Branch)
 }
