@@ -11,16 +11,16 @@ import (
 // ChangeParent changes the parent of the given branch to the given parent.
 // Use SetParent to set the parent if no parent existed before.
 type ChangeParent struct {
-	Branch gitdomain.LocalBranchName
-	Parent gitdomain.LocalBranchName
-	undeclaredOpcodeMethods
+	Branch                  gitdomain.LocalBranchName
+	Parent                  gitdomain.LocalBranchName
+	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
 func (self *ChangeParent) Run(args shared.RunArgs) error {
-	err := args.Runner.Config.SetParent(self.Branch, self.Parent)
+	err := args.Config.SetParent(self.Branch, self.Parent)
 	if err != nil {
 		return err
 	}
-	args.Runner.FinalMessages.Add(fmt.Sprintf(messages.BranchParentChanged, self.Branch, self.Parent))
+	args.FinalMessages.Add(fmt.Sprintf(messages.BranchParentChanged, self.Branch, self.Parent))
 	return nil
 }
