@@ -7,11 +7,11 @@ import (
 
 // DeleteParentBranch removes the parent branch entry in the Git Town configuration.
 type DeleteParentBranch struct {
-	Branch gitdomain.LocalBranchName
-	undeclaredOpcodeMethods
+	Branch                  gitdomain.LocalBranchName
+	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
 func (self *DeleteParentBranch) Run(args shared.RunArgs) error {
-	args.Runner.Config.RemoveParent(self.Branch)
+	args.Config.RemoveParent(self.Branch)
 	return nil
 }
