@@ -3,11 +3,11 @@ package opcodes
 import "github.com/git-town/git-town/v14/src/vm/shared"
 
 type QueueMessage struct {
-	Message string
-	undeclaredOpcodeMethods
+	Message                 string
+	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
 func (self *QueueMessage) Run(args shared.RunArgs) error {
-	args.Runner.FinalMessages.Add(self.Message)
+	args.FinalMessages.Add(self.Message)
 	return nil
 }
