@@ -6,10 +6,10 @@ import (
 )
 
 type RemoveGlobalConfig struct {
-	Key gitconfig.Key // the config key to remove
-	undeclaredOpcodeMethods
+	Key                     gitconfig.Key // the config key to remove
+	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
 func (self *RemoveGlobalConfig) Run(args shared.RunArgs) error {
-	return args.Runner.Config.GitConfig.RemoveGlobalConfigValue(self.Key)
+	return args.Config.GitConfig.RemoveGlobalConfigValue(self.Key)
 }
