@@ -6,10 +6,10 @@ import (
 )
 
 type RemoveLocalConfig struct {
-	Key gitconfig.Key // the config key to remove
-	undeclaredOpcodeMethods
+	Key                     gitconfig.Key // the config key to remove
+	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
 func (self *RemoveLocalConfig) Run(args shared.RunArgs) error {
-	return args.Runner.Config.GitConfig.RemoveLocalConfigValue(self.Key)
+	return args.Config.GitConfig.RemoveLocalConfigValue(self.Key)
 }
