@@ -6,11 +6,11 @@ import (
 )
 
 type SetLocalConfig struct {
-	Key   gitconfig.Key
-	Value string
-	undeclaredOpcodeMethods
+	Key                     gitconfig.Key
+	Value                   string
+	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
 func (self *SetLocalConfig) Run(args shared.RunArgs) error {
-	return args.Runner.Config.GitConfig.SetLocalConfigValue(self.Key, self.Value)
+	return args.Config.GitConfig.SetLocalConfigValue(self.Key, self.Value)
 }
