@@ -12,7 +12,7 @@ import (
 )
 
 // Save stores the given run state for the given Git repo to disk.
-func Save(runState *runstate.RunState, repoDir gitdomain.RepoRootDir) error {
+func Save(runState runstate.RunState, repoDir gitdomain.RepoRootDir) error {
 	content, err := json.MarshalIndent(runState, "", "  ")
 	if err != nil {
 		return fmt.Errorf(messages.RunstateSerializeProblem, err)
