@@ -11,6 +11,7 @@ import (
 	"github.com/git-town/git-town/v14/src/config/gitconfig"
 	prodgit "github.com/git-town/git-town/v14/src/git"
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	. "github.com/git-town/git-town/v14/src/gohacks/prelude"
 	"github.com/git-town/git-town/v14/src/gohacks/slice"
 	"github.com/git-town/git-town/v14/src/gohacks/stringslice"
 	"github.com/git-town/git-town/v14/test/asserts"
@@ -147,13 +148,8 @@ func (self *TestCommands) CreateContributionBranches(names ...gitdomain.LocalBra
 
 // CreateFeatureBranch creates a feature branch with the given name in this repository.
 func (self *TestCommands) CreateFeatureBranch(name gitdomain.LocalBranchName) {
-	err := self.RunMany([][]string{
-		{"git", "branch", name.String(), "main"},
-		{"git", "config", "git-town-branch." + name.String() + ".parent", "main"},
-	})
-	if err != nil {
-		panic(err)
-	}
+	self.MustRun("git", "branch", name.String(), "main")
+	self.MustRun("git", "config", "git-town-branch."+name.String()+".parent", "main")
 }
 
 // CreateFile creates a file with the given name and content in this repository.
@@ -282,12 +278,12 @@ func (self *TestCommands) FilesInCommit(sha gitdomain.SHA) []string {
 	return strings.Split(output, "\n")
 }
 
-func (self *TestCommands) GlobalGitConfig(name gitconfig.Key) *string {
+func (self *TestCommands) GlobalGitConfig(name gitconfig.Key) Option[string] {
 	output, err := self.Query("git", "config", "--global", "--get", name.String())
 	if err != nil {
-		return nil
+		return None[string]()
 	}
-	return &output
+	return Some(output)
 }
 
 // HasBranchesOutOfSync indicates whether one or more local branches are out of sync with their tracking branch.
@@ -315,12 +311,9 @@ func (self *TestCommands) LineageTable() datatable.DataTable {
 	result := datatable.DataTable{}
 	result.AddRow("BRANCH", "PARENT")
 	_, localGitConfig, _ := self.Config.GitConfig.LoadLocal(false) // we ignore the Git cache here because reloading a config in the middle of a Git Town command doesn't change the cached initial state of the repo
-	if localGitConfig.Lineage == nil {
-		return result
-	}
 	lineage := localGitConfig.Lineage
 	for _, branchName := range lineage.BranchNames() {
-		result.AddRow(branchName.String(), lineage[branchName].String())
+		result.AddRow(branchName.String(), lineage.Parent(branchName).String())
 	}
 	result.Sort()
 	return result
@@ -352,12 +345,12 @@ func (self *TestCommands) LocalBranchesMainFirst(mainBranch gitdomain.LocalBranc
 	return branches, nil
 }
 
-func (self *TestCommands) LocalGitConfig(name gitconfig.Key) *string {
+func (self *TestCommands) LocalGitConfig(name gitconfig.Key) Option[string] {
 	output, err := self.Query("git", "config", "--local", "--get", name.String())
 	if err != nil {
-		return nil
+		return None[string]()
 	}
-	return &output
+	return Some(output)
 }
 
 func (self *TestCommands) MergeBranch(branch gitdomain.LocalBranchName) error {
@@ -444,10 +437,8 @@ func (self *TestCommands) StageFiles(names ...string) {
 
 // StashOpenFiles stashes the open files away.
 func (self *TestCommands) StashOpenFiles() {
-	self.MustRunMany([][]string{
-		{"git", "add", "-A"},
-		{"git", "stash"},
-	})
+	self.MustRun("git", "add", "-A")
+	self.MustRun("git", "stash")
 }
 
 // Tags provides a list of the tags in this repository.
