@@ -159,8 +159,8 @@ func TestTestCommands(t *testing.T) {
 		runtime.Config.Reload()
 		must.False(t, runtime.Config.Config.IsMainOrPerennialBranch(gitdomain.NewLocalBranchName("f1")))
 		lineageHave := runtime.Config.Config.Lineage
-		lineageWant := configdomain.Lineage{}
-		lineageWant[gitdomain.NewLocalBranchName("f1")] = gitdomain.NewLocalBranchName("main")
+		lineageWant := configdomain.NewLineage()
+		lineageWant.Add(gitdomain.NewLocalBranchName("f1"), gitdomain.NewLocalBranchName("main"))
 		must.Eq(t, lineageWant, lineageHave)
 	})
 
