@@ -8,8 +8,10 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/cucumber/messages-go/v10"
+	"github.com/cucumber/godog"
+
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	. "github.com/git-town/git-town/v14/src/gohacks/prelude"
 	"github.com/git-town/git-town/v14/src/gohacks/stringslice"
 	"github.com/sergi/go-diff/diffmatchpatch"
 	"golang.org/x/exp/maps"
@@ -23,7 +25,7 @@ type DataTable struct {
 }
 
 // FromGherkin provides a DataTable instance populated with data from the given Gherkin table.
-func FromGherkin(table *messages.PickleStepArgument_PickleTable) DataTable {
+func FromGherkin(table *godog.Table) DataTable {
 	result := DataTable{}
 	for _, tableRow := range table.Rows {
 		resultRow := make([]string, len(tableRow.Cells))
@@ -56,7 +58,7 @@ func (self DataTable) EqualDataTable(other DataTable) (diff string, errorCount i
 
 // EqualGherkin compares this DataTable instance to the given Gherkin self.
 // If both are equal it returns an empty string, otherwise a diff printable on the console.
-func (self *DataTable) EqualGherkin(other *messages.PickleStepArgument_PickleTable) (diff string, errorCount int) {
+func (self *DataTable) EqualGherkin(other *godog.Table) (diff string, errorCount int) {
 	if len(self.Cells) == 0 {
 		return "your data is empty", 1
 	}
@@ -65,7 +67,7 @@ func (self *DataTable) EqualGherkin(other *messages.PickleStepArgument_PickleTab
 }
 
 // Expand returns a new DataTable instance with the placeholders in this datatable replaced with the given values.
-func (self *DataTable) Expand(localRepo runner, remoteRepo runner, worktreeRepo runner, initialDevSHAs map[string]gitdomain.SHA, initialOriginSHAs map[string]gitdomain.SHA, initialWorktreeSHAs map[string]gitdomain.SHA) DataTable {
+func (self *DataTable) Expand(localRepo runner, remoteRepo runner, worktreeRepo runner, initialDevSHAs map[string]gitdomain.SHA, initialOriginSHAsOpt, initialWorktreeSHAsOpt Option[map[string]gitdomain.SHA]) DataTable {
 	var templateRE *regexp.Regexp
 	var templateOnce sync.Once
 	result := DataTable{}
@@ -100,6 +102,10 @@ func (self *DataTable) Expand(localRepo runner, remoteRepo runner, worktreeRepo
 					}
 					cell = strings.Replace(cell, match, sha.String(), 1)
 				case strings.HasPrefix(match, "{{ sha-in-origin-before-run "):
+					initialOriginSHAs, has := initialOriginSHAsOpt.Get()
+					if !has {
+						panic("no origin SHAs recorded")
+					}
 					commitName := match[29 : len(match)-4]
 					sha, found := initialOriginSHAs[commitName]
 					if !found {
@@ -117,6 +123,10 @@ func (self *DataTable) Expand(localRepo runner, remoteRepo runner, worktreeRepo
 					cell = strings.Replace(cell, match, sha.String(), 1)
 				case strings.HasPrefix(match, "{{ sha-in-worktree-before-run "):
 					commitName := match[31 : len(match)-4]
+					initialWorktreeSHAs, has := initialWorktreeSHAsOpt.Get()
+					if !has {
+						panic("no initial worktree SHAs recorded")
+					}
 					sha, found := initialWorktreeSHAs[commitName]
 					if !found {
 						fmt.Printf("I cannot find the initial worktree commit %q.\n", commitName)
