@@ -41,7 +41,6 @@ func Create(t *testing.T) TestRuntime {
 	err = os.Mkdir(homeDir, 0o744)
 	must.NoError(t, err)
 	runtime := Initialize(workingDir, homeDir, homeDir)
-	err = runtime.Run("git", "commit", "--allow-empty", "-m", "initial commit")
 	must.NoError(t, err)
 	return runtime
 }
@@ -63,11 +62,10 @@ func CreateGitTown(t *testing.T) TestRuntime {
 // including necessary Git configuration to make commits. Creates missing folders as needed.
 func Initialize(workingDir, homeDir, binDir string) TestRuntime {
 	runtime := New(workingDir, homeDir, binDir)
-	runtime.MustRunMany([][]string{
-		{"git", "init", "--initial-branch=initial"},
-		{"git", "config", "--global", "user.name", "user"},
-		{"git", "config", "--global", "user.email", "email@example.com"},
-	})
+	runtime.MustRun("git", "init", "--initial-branch=initial")
+	runtime.MustRun("git", "config", "--global", "user.name", "user")
+	runtime.MustRun("git", "config", "--global", "user.email", "email@example.com")
+	runtime.MustRun("git", "commit", "--allow-empty", "-m", "initial commit")
 	return runtime
 }
 
@@ -95,7 +93,7 @@ func New(workingDir, homeDir, binDir string) TestRuntime {
 	})
 	validatedConfig := config.ValidatedConfig{
 		Config: configdomain.ValidatedConfig{
-			UnvalidatedConfig: unvalidatedConfig.Config,
+			UnvalidatedConfig: unvalidatedConfig.Config.Value,
 			GitUserEmail:      "test@test.com",
 			GitUserName:       "Tester",
 			MainBranch:        gitdomain.NewLocalBranchName("main"),
